@@ -44,8 +44,6 @@ class ConfigTypes(Enum):
     # Payment
     PAYMENT_WEBSITE = auto(),
     PAYMENT_CHECK_ON_JOIN = auto(),
-    PAYMENT_CHECK_PERIOD_MIN = auto(),
-    PAYMENT_CHECK_CHAT_IDS = auto()
     PAYMENT_TYPE = auto(),
     PAYMENT_EXCEL_FILE = auto(),
     PAYMENT_GOOGLE_SHEET_ID = auto(),
@@ -64,14 +62,13 @@ class ConfigTypes(Enum):
     EMAIL_PASSWORD = auto(),
     EMAIL_SUBJECT = auto(),
     EMAIL_ALT_BODY = auto(),
-    EMAIL_ALT_BODY_FILE = auto(),
     EMAIL_HTML_BODY = auto(),
-    EMAIL_HTML_BODY_FILE = auto(),
     # Logging
     LOG_LEVEL = auto(),
     LOG_CONSOLE_ENABLED = auto(),
     LOG_FILE_ENABLED = auto(),
     LOG_FILE_NAME = auto(),
+    LOG_FILE_USE_ROTATING = auto(),
     LOG_FILE_APPEND = auto(),
     LOG_FILE_MAX_BYTES = auto(),
     LOG_FILE_BACKUP_CNT = auto(),
@@ -81,6 +78,11 @@ class ConfigTypes(Enum):
 # Classes
 #
 
+# Configuration error class
+class ConfigError(Exception):
+    pass
+
+
 # Configuration class
 class Config:
     # Constructor
@@ -103,3 +105,8 @@ class Config:
             raise TypeError("Config type is not an enumerative of ConfigTypes")
 
         self.config[config_type] = value
+
+    # Get if value is set
+    def IsValueSet(self,
+                   config_type: ConfigTypes) -> bool:
+        return config_type in self.config
