@@ -24,6 +24,7 @@
 import pyrogram
 from typing import Optional
 from telegram_payment_bot.config import Config
+from telegram_payment_bot.helpers import MemberHelper
 from telegram_payment_bot.logger import Logger
 from telegram_payment_bot.chat_members import ChatMembersList, ChatMembersGetter
 from telegram_payment_bot.payments_loader_factory import PaymentsLoaderFactory
@@ -65,7 +66,7 @@ class MembersPaymentGetter:
         chat_members_getter = ChatMembersGetter(self.client, self.config)
         return chat_members_getter.FilterMembers(
             chat,
-            lambda member: member.status == "member" and
+            lambda member: MemberHelper.IsValidMember(member) and
                            member.user.username is not None and
                            not payments.IsExpiredByUsername(member.user.username)
         )
@@ -84,7 +85,7 @@ class MembersPaymentGetter:
         chat_members_getter = ChatMembersGetter(self.client, self.config)
         return chat_members_getter.FilterMembers(
             chat,
-            lambda member: member.status == "member" and
+            lambda member: MemberHelper.IsValidMember(member) and
                            (member.user.username is None or
                             payments.IsExpiredByUsername(member.user.username))
         )
@@ -104,7 +105,7 @@ class MembersPaymentGetter:
         chat_members_getter = ChatMembersGetter(self.client, self.config)
         return chat_members_getter.FilterMembers(
             chat,
-            lambda member: member.status == "member" and
+            lambda member: MemberHelper.IsValidMember(member) and
                            (member.user.username is None or
                             payments.IsExpiringInDaysByUsername(member.user.username, days))
         )
